cocos package — cocos v0.6.5 documentation

# cocos package

## Subpackages

- cocos.actions package
  - Submodules
    - cocos.actions.base_actions module
      - Actions
        - Action instance roles
          - Template Role
          - Worker role
          - Component role
        - Restrictions and Capabilities for the current design and implementation
          - Worker Independence
          - A worker action instance should not be used as a template
          - Posible fights between worker actions over a target member
          - Action’s instances in the template role must be (really) deepcopyiable
        - Overview main subclasses
          - InstantAction
          - IntervalAction
          - Action
    - cocos.actions.basegrid_actions module
      - Grid Actions
    - cocos.actions.camera_actions module
    - cocos.actions.grid3d_actions module
    - cocos.actions.instant_actions module
      - Instant Actions
    - cocos.actions.interval_actions module
      - Interval Actions
      - Available IntervalActions
      - Modifier actions
    - cocos.actions.move_actions module
    - cocos.actions.quadmoveby_actions module
    - cocos.actions.tiledgrid_actions module
  - Module contents
- cocos.audio package
  - Subpackages
    - cocos.audio.SDL package
      - Submodules
        - cocos.audio.SDL.array module
        - cocos.audio.SDL.audio module
        - cocos.audio.SDL.constants module
        - cocos.audio.SDL.darwin module
        - cocos.audio.SDL.dll module
        - cocos.audio.SDL.endian module
        - cocos.audio.SDL.error module
        - cocos.audio.SDL.mixer module
        - cocos.audio.SDL.rwops module
        - cocos.audio.SDL.sound module
        - cocos.audio.SDL.timer module
        - cocos.audio.SDL.version module
      - Module contents
    - cocos.audio.pygame package
      - Submodules
        - cocos.audio.pygame.base module
        - cocos.audio.pygame.mixer module
        - cocos.audio.pygame.music module
        - cocos.audio.pygame.version module
      - Module contents
  - Submodules
    - cocos.audio.actions module
    - cocos.audio.effect module
    - cocos.audio.exceptions module
    - cocos.audio.music module
  - Module contents
- cocos.layer package
  - Submodules
    - cocos.layer.base_layers module
    - cocos.layer.python_interpreter module
    - cocos.layer.scrolling module
    - cocos.layer.util_layers module
  - Module contents
- cocos.scenes package
  - Submodules
    - cocos.scenes.pause module
    - cocos.scenes.sequences module
    - cocos.scenes.transitions module
  - Module contents

## Submodules

- cocos.batch module
  - Batches
- cocos.camera module
- cocos.cocosnode module
- cocos.collision_model module
- cocos.compat module
- cocos.custom_clocks module
- cocos.director module
  - Initializing
  - Running a Scene
- cocos.draw module
- cocos.euclid module
- cocos.fps module
- cocos.framegrabber module
- cocos.gl_framebuffer_object module
- cocos.grid module
- cocos.mapcolliders module
- cocos.menu module
  - Menu
- cocos.particle module
- cocos.particle_systems module
- cocos.path module
- cocos.rect module
- cocos.scene module
- cocos.shader module
- cocos.skeleton module
- cocos.sprite module
  - Animating a sprite
  - Changing a sprite by way of actions
- cocos.text module
- cocos.tiles module
- cocos.utils module
- cocos.wired module

## Module contents

a framework for building 2D games, demos, and other graphical/interactive applications.

### Main Features

> - Flow control: Manage the flow control between different scenes in an easy way
> - Sprites: Fast and easy sprites
> - Actions: Just tell sprites what you want them to do. Composable actions like move, rotate, scale and much more
> - Effects: Effects like waves, twirl, lens and much more
> - Tiled Maps: Support for rectangular and hexagonal tiled maps
> - Collision: Basic pure python support for collisions
> - Transitions: Move from scene to scene with style
> - Menus: Built in classes to create menus
> - Text Rendering: Label and HTMLLabel with action support
> - Documentation: Programming Guide + API Reference + Video Tutorials + Lots of simple tests showing how to use it
> - Built-in Python Interpreter: For debugging purposes
> - BSD License: Just use it
> - Pyglet Based: No external dependencies
> - OpenGL Based: Hardware Acceleration

http://python.cocos2d.org